@@ -34,7 +34,7 @@ from tinydav.exception import HTTPError, HTTPUserError, HTTPServerError
 
 __author__ = "Manuel Hermann <manuel-hermann@gmx.net>"
 __license__ = "LGPL"
-__version__ = "0.6.5"
+__version__ = "0.6.6"
 
 __all__ = (
     "HTTPError", "HTTPUserError", "HTTPServerError",
@@ -189,16 +189,13 @@ class WebDAVResponse(HTTPResponse):
 
     def _parse_xml_content(self):
         """Parse the XML content.
-        
+
         If the response content cannot be parsed as XML content, 
         <root><empty/></root> will be taken as content instead.
 
         """
         try:
-            if self.content is None:
-                parse_me = self.response
-            else:
-                parse_me = StringIO(self.content)
+            parse_me = StringIO(self.content)
             self._etree.parse(parse_me)
         except ExpatError, e:
             self.parse_error = e
@@ -295,12 +292,12 @@ class WebDAVLockResponse(WebDAVResponse):
             self._client = client
             self._uri = uri
             self._tag = util.make_absolute(self._client, uri)
+        # RFC 2518, 8.10.4 Depth and Locking
+        # If the lock cannot be granted to all resources, a 409 (Conflict)
+        # status code MUST be returned with a response entity body
+        # containing a multistatus XML element describing which resource(s)
+        # prevented the lock from being granted.
         elif self == CONFLICT:
-            # RFC 2518, 8.10.4 Depth and Locking
-            # If the lock cannot be granted to all resources, a 409 (Conflict)
-            # status code MUST be returned with a response entity body
-            # containing a multistatus XML element describing which resource(s)
-            # prevented the lock from being granted.
             self._set_multistatus()
 
     def __repr__(self):
@@ -344,6 +341,7 @@ class WebDAVLockResponse(WebDAVResponse):
         if "If" in self._client.headers:
             if self._previous_if is not None:
                 self._client.headers["If"] = self._previous_if
+                self._previous_if = None
             else:
                 del self._client.headers["If"]
 
@@ -359,7 +357,7 @@ class WebDAVLockResponse(WebDAVResponse):
             # <!ELEMENT shared EMPTY >
             scope = ACTIVELOCK + "/{DAV:}lockscope/*"
             self._lockscope = self._etree.find(scope)
-        return self._locktype
+        return self._lockscope
 
     @property
     def locktype(self):
@@ -393,12 +391,12 @@ class WebDAVLockResponse(WebDAVResponse):
 
     @property
     def timeout(self):
-        """Return the timeout of this lock or None, if no owner is available."""
-        if self._owner is None:
+        """Return the timeout of this lock or None, if not available."""
+        if self._timeout is None:
             # RFC 2518, 12.1.3 timeout XML Element
             # <!ELEMENT timeout (#PCDATA) >
             timeout = ACTIVELOCK + "/{DAV:}timeout"
-            self._timeout = self._etree.findtext(timeout)
+            self._timeout = self._etree.findtext(timeout).strip()
         return self._timeout
 
     @property
@@ -408,7 +406,8 @@ class WebDAVLockResponse(WebDAVResponse):
             # RFC 2518, 12.1.2 locktoken XML Element
             # <!ELEMENT locktoken (href+) >
             token = ACTIVELOCK + "/{DAV:}locktoken/{DAV:}href"
-            self._locktokens = [t.text for t in self._etree.findall(token)]
+            self._locktokens = [t.text.strip()
+                                for t in self._etree.findall(token)]
         return self._locktokens
 
 
@@ -460,7 +459,7 @@ class MultiStatusResponse(int):
                 DAV properties.
 
         """
-        # check, whether its a default DAV property name
+        # check, whether it's a default DAV property name
         if not name.startswith("{"):
             name = "{DAV:}%s" % name
         # RFC 2518, 12.9.1.1 propstat XML Element
@@ -821,7 +820,7 @@ class HTTPClient(object):
         """Make PUT request and return status.
 
         uri -- Path for PUT.
-        fileobject -- File-like object with content to PUT.
+        fileobject -- File-like object or string with content to PUT.
         content_type -- The content-type of the file. Default value is
                         application/octet-stream.
         headers -- If given, must be a dict with headers to send.
